@@ -15,13 +15,8 @@
 #' @param label name of the model. By default it’s extracted from the class attribute of the model
 #' @param method an estimation method of SHAP values. Currently the only availible is `KernelSHAP`.
 #' @param nsamples number of samples or "auto". Note that number must be as integer. Use `as.integer()`.
-#' 
 #'
-#' In order to use shapper with other python virtual environment following R command are required to execute 
-#' reticulate::use_virtualenv("path_to_your_env")
-#' or for conda
-#' reticulate::use_conda("name_of_conda_env")
-#' before attaching shapper.
+#'
 #'
 #' @return an object of class individual_variable_effect with shap values of each variable for each new observation.
 #' Columns:
@@ -37,7 +32,11 @@
 #'   \item _label_ a label
 #' }
 #'
-#'
+#' In order to use shapper with other python virtual environment following R command are required to execute
+#' reticulate::use_virtualenv("path_to_your_env")
+#' or for conda
+#' reticulate::use_conda("name_of_conda_env")
+#' before attaching shapper.
 #'
 #' @importFrom reticulate r_to_py
 #'
@@ -84,7 +83,7 @@ individual_variable_effect.explainer <- function(x,
   data <- x$data
   predict_function <- x$predict_function
   label <- x$label
-  
+
   individual_variable_effect.default(
     model,
     data,
@@ -110,6 +109,10 @@ individual_variable_effect.default <-
            method = "KernelSHAP",
            nsamples = "auto",
            ...) {
+    # check if data correct
+    if(!all(colnames(data)==colnames(new_observation))){
+      stop("Columns in new obseravtion and data does not match")
+    }
     # transform factors to numerics and keep factors' levels
     data_classes <- sapply(data, class)
     factors <- list()
@@ -120,11 +123,11 @@ individual_variable_effect.default <-
         data_numeric[, col] <- as.numeric(data_numeric[, col]) - 1
       }
     }
-    
+
     # force nsamples to be an integer
     if (is.numeric(nsamples))
       nsamples <- as.integer(round(nsamples))
-    
+
     p_function <- function(new_data) {
       new_data <- as.data.frame(new_data)
       colnames(new_data) <- colnames(data)
@@ -142,8 +145,8 @@ individual_variable_effect.default <-
       return(res)
     }
     explainer = shap_reference$KernelExplainer(p_function, data_numeric)
-    
-    
+
+
     new_observation_releveled <- new_observation
     new_observation_numeric <- new_observation
     for (col in names(factors)) {
@@ -154,15 +157,15 @@ individual_variable_effect.default <-
     }
     shap_values = explainer$shap_values(new_observation_numeric, nsamples = nsamples)
     expected_value = explainer$expected_value
-    
-    
+
+
     predictions <- predict_function(x, new_observation_releveled)
     variables <- colnames(data)
-    
+
     # create data to return
     new_data <- new_observation
     new_data$`_id_` <- c(1:nrow(new_data))
-    
+
     # add multiple predictions
     new_data <-
       new_data[rep(1:nrow(new_data), each = length(shap_values)),]
@@ -176,11 +179,11 @@ individual_variable_effect.default <-
     new_data$`_yhat_` <- as.vector(t(predictions))
     new_data$`_yhat_mean_` <-
       rep(expected_value, times = nrow(new_observation))
-    
+
     # add multiple variables
     new_data <- new_data[rep(1:nrow(new_data), each = ncol(data)),]
     new_data$`_vname_` <- rep(variables, times = length(predictions))
-    
+
     attribution <- numeric()
     for (i in 1:nrow(new_observation)) {
       for (j in 1:length(shap_values)) {
@@ -193,10 +196,10 @@ individual_variable_effect.default <-
       }
     }
     new_data$`_attribution_` <- attribution
-    new_data$`_sign_` <- factor(sign(new_data$`_attribution`))
+    new_data$`_sign_` <- factor(sign(new_data$`_attribution_`))
     new_data$`_sign_` <- ifelse(new_data$`_sign_` == 1, "+", "-")
     new_data$`_label_` <- label
-    
+
     class(new_data) <- c("individual_variable_effect", "data.frame")
     return(new_data)
   }
